ghinbox

Repository:
Checking auth...
Show comments (Issues) Show comments (PRs) Hide uninteresting comments
Rate limit: unknown
No rate limit requests logged yet.

## Notifications

Order:
Select all
Loading notifications...

### No notifications

Enter a repository and click Quick Sync to load notifications.

### Keyboard Shortcuts

#### Navigation

Move down
`j`
Move up
`k`
Scroll to top
`g` `g`
Scroll to bottom
`G`
Open notification
`Enter`

#### Actions

Mark as done
`e`
Unsubscribe
`m`
Undo last action
`u`
Reload page
`r`

#### Selection

Toggle selection
`t`
Select all
`Ctrl` `a`
Clear selection
`Esc`

#### Help

Show this help
`?`